@@ -20,10 +20,10 @@ topn = 50
 workers = 10
 data_dir = PKG_PATH.joinpath('.cache')
 no_rerank = False
-model = ''
-model_dir = 'pt-tinybert-msmarco'
+model = 'PtTransformersRerankPlugin'
+model_dir = 'nboost/pt-tinybert-msmarco'
 qa = False
-qa_model = ''
+qa_model = 'PtDistilBertQAModelPlugin'
 qa_model_dir = 'distilbert-base-uncased-distilled-squad'
 qa_threshold = 0
 max_query_length = 64
